==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/hu-HU/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'A Helyekről',
    'about_locations'           => 'A helyek a felhasználók, az eszközök és egyéb elemek helyadatait nyomon követik',
    'assets_rtd'                => 'Eszközök', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Hozzárendelt eszközök',
    'id'                        => 'ID',
    'city'                      => 'Város',
    'state'                     => 'Megye',
    'country'                   => 'Ország',
    'create'                    => 'Helyszín létrehozása',
    'update'                    => 'Helyszín frissítése',
    'print_assigned'            => 'Hozzárendelt nyomtatása',
    'print_all_assigned'        => 'Az összes hozzárendelt nyomtatása',
    'name'                      => 'Helyszín neve',
    'address'                   => 'Cím',
    'address2'                   => 'Cím sor 2',
    'zip'                       => 'Irányítószám',
    'locations'                 => 'Helyek',
    'parent'                    => 'Szülő',
    'currency'                  => 'Helyi valuta',
    'ldap_ou'                   => 'LDAP keresés OU',
    'user_name'                 => 'Felhasználónév',
    'department'                => 'Osztály',
    'location'                  => 'Helyszín',
    'asset_tag'                 => 'Eszköz azonosító',
    'asset_name'                => 'Név',
    'asset_category'            => 'Kategória',
    'asset_manufacturer'        => 'Gyártó',
    'asset_model'               => 'Modell',
    'asset_serial'              => 'Sorozatszám',
    'asset_location'            => 'Helyszín',
    'asset_checked_out'         => 'Kiadva',
    'asset_expected_checkin'    => 'Várható visszavétel dátuma',
    'date'                      => 'Dátum:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Aláírva (Vagyonellenőr):',
    'signed_by_finance_auditor' => 'Aláírta (Pénzügyi könyvvizsgáló):',
    'signed_by_location_manager' => 'Aláírva (Helykezelő):',
    'signed_by'                 => 'Aláírta:',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/hu-HU/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'A Helyekről',
    'about_locations'           => 'A helyek a felhasználók, az eszközök és egyéb elemek helyadatait nyomon követik',
    'assets_rtd'                => 'Eszközök', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Hozzárendelt eszközök',
    'id'                        => 'ID',
    'city'                      => 'Város',
    'state'                     => 'Megye',
    'country'                   => 'Ország',
    'create'                    => 'Helyszín létrehozása',
    'update'                    => 'Helyszín frissítése',
    'print_assigned'            => 'Hozzárendelt nyomtatása',
    'print_all_assigned'        => 'Az összes hozzárendelt nyomtatása',
    'name'                      => 'Helyszín neve',
    'address'                   => 'Cím',
    'address2'                   => 'Cím sor 2',
    'zip'                       => 'Irányítószám',
    'locations'                 => 'Helyek',
    'parent'                    => 'Szülő',
    'currency'                  => 'Helyi valuta',
    'ldap_ou'                   => 'LDAP keresés OU',
    'user_name'                 => 'Felhasználónév',
    'department'                => 'Osztály',
    'location'                  => 'Helyszín',
    'asset_tag'                 => 'Eszköz azonosító',
    'asset_name'                => 'Név',
    'asset_category'            => 'Kategória',
    'asset_manufacturer'        => 'Gyártó',
    'asset_model'               => 'Modell',
    'asset_serial'              => 'Sorozatszám',
    'asset_location'            => 'Helyszín',
    'asset_checked_out'         => 'Kiadva',
    'asset_expected_checkin'    => 'Várható visszavétel dátuma',
    'date'                      => 'Dátum:',
    'phone'                     => 'Helyszín telefonszáma',
    'signed_by_asset_auditor'   => 'Aláírva (Vagyonellenőr):',
    'signed_by_finance_auditor' => 'Aláírta (Pénzügyi könyvvizsgáló):',
    'signed_by_location_manager' => 'Aláírva (Helykezelő):',
    'signed_by'                 => 'Aláírta:',
];
